@@ -19,7 +19,7 @@ WCF_ROOT = os.path.abspath(os.path.dirname(__file__))
 sys.path.insert(0, WCF_ROOT)
 import wcf_pb2  # noqa
 
-__version__ = "3.7.0.30.15.2"
+__version__ = "3.7.0.30.16"
 
 
 def _retry():
@@ -34,7 +34,7 @@ def _retry():
                 except Exception as e:
                     func_name = re.findall(r"func: (.*?)\n", str(args[1]))[-1]
                     logging.getLogger("WCF").error(f"Call {func_name} failed: {e}")
-                    ret = None
+                    ret = wcf_pb2.Response()
 
             return ret
         return wrapper
